import gzip


from huobi.model import *


class OrderListRequest:
    """
    The order update received by request of order list.

    :member
        symbol: The symbol you subscribed.
        timestamp: The UNIX formatted timestamp generated by server in UTC.
        topic: request topic
        client_req_id: client request ID
        order_list : order list

    """

    def __init__(self):
        self.symbol = ""
        self.timestamp = 0
        self.client_req_id = ""
        self.topic = ""
        self.order_list = list()

    @staticmethod
    def json_parse(json_data, account_type_map):
        req_obj = OrderListRequest()
        error_code = json_data.get_int("err-code")
        req_obj.timestamp = json_data.get_int("ts")
        req_obj.client_req_id = json_data.get_string("cid")
        req_obj.topic = json_data.get_string("topic")
        req_obj.symbol = json_data.get_string_or_default("symbol", "")
        if error_code == 0:   # only get data for successful request
            order_list_json = json_data.get_array("data")

            order_list = list()
            for order_json in order_list_json.get_items():
                account_id = order_json.get_int("account-id")
                account_type = AccountType.INVALID
                if account_id in account_type_map:
                    account_type = account_type_map[account_id]
                order_obj = Order.json_parse(order_json, account_type)
                order_list.append(order_obj)
            req_obj.order_list = order_list

        return req_obj

    @staticmethod
    def update_symbol(req_obj: 'OrderListRequest', symbol=None):
        if symbol and len(symbol):
            req_obj.symbol = symbol   # update by setting value
        else:
            if len(req_obj.order_list):
                for order_obj in req_obj.order_list:
                    req_obj.symbol = order_obj.symbol   # update by order symbol
                    break

        return req_obj

    def print_object(self, format_data=""):
        from huobi.base.printobject import PrintBasic
        PrintBasic.print_basic(self.symbol, "Symbol")
        PrintBasic.print_basic(self.timestamp, "Timestamp")
        PrintBasic.print_basic(self.client_req_id, "Client Req ID")
        PrintBasic.print_basic(self.topic, "Topic")
        print("Order List as below : count " + str(len(self.order_list)))
        if len(self.order_list):
            for order_obj in self.order_list:
                order_obj.print_object("\t ")
                print()




