

class Trade:
    """
    The trade information with price and amount etc.

    :member
        price: The trading price in quote currency.
        amount: The trading volume in base currency.
        trade_id: The unique trade id of this trade.
        timestamp: The UNIX formatted timestamp generated by server in UTC.
        direction: The direction of the taker trade: 'buy' or 'sell'.
    """

    def __init__(self):
        self.price = 0.0
        self.amount = 0.0
        self.trade_id = 0
        self.unique_trade_id = 0
        self.timestamp = 0
        self.direction = ""

    @staticmethod
    def json_parse(json_data):
        trade = Trade()
        trade.amount = json_data.get_float("amount")
        trade.price = json_data.get_float("price")
        trade.trade_id = json_data.get_string("id")
        trade.unique_trade_id = json_data.get_int_or_default("trade-id", json_data.get_int_or_default("tradeId", 0))
        trade.direction = json_data.get_string("direction")
        trade.timestamp = json_data.get_int("ts")
        return trade

    def print_object(self, format_data=""):
        from huobi.base.printobject import PrintBasic
        PrintBasic.print_basic(self.trade_id, format_data + "Id")
        PrintBasic.print_basic(self.unique_trade_id, format_data + "Trade Id")
        PrintBasic.print_basic(self.timestamp, format_data + "Trade Time")
        PrintBasic.print_basic(self.price, format_data + "Price")
        PrintBasic.print_basic(self.amount, format_data + "Amount")
        PrintBasic.print_basic(self.direction, format_data + "Direction")