class TradeStatistics:
    """
    The summary of trading in the market for the last 24 hours

    :member
        timestamp: The UNIX formatted timestamp generated by server in UTC.
        open: The opening price of last 24 hours.
        close: The last price of last 24 hours.
        amount: The aggregated trading volume in USDT.
        high: The high price of last 24 hours.
        low: The low price of last 24 hours.
        count: The number of completed trades.
        volume: The trading volume in base currency of last 24 hours.
    """

    def __init__(self):
        self.timestamp = 0
        self.open = 0.0
        self.close = 0.0
        self.amount = 0.0
        self.high = 0.0
        self.low = 0.0
        self.count = 0
        self.volume = 0.0

    @staticmethod
    def json_parse(json_data, ts):
        statistics = TradeStatistics()
        statistics.amount = json_data.get_float("amount")
        statistics.open = json_data.get_float("open")
        statistics.close = json_data.get_float("close")
        statistics.high = json_data.get_float("high")
        statistics.timestamp = ts
        statistics.count = json_data.get_int("count")
        statistics.low = json_data.get_float("low")
        statistics.volume = json_data.get_float("vol")
        return statistics

    def print_object(self, format_data=""):
        from huobi.base.printobject import PrintBasic
        PrintBasic.print_basic(self.timestamp, format_data + "Timestamp")
        PrintBasic.print_basic(self.open, format_data + "Open")
        PrintBasic.print_basic(self.close, format_data + "Close")
        PrintBasic.print_basic(self.amount, format_data + "Amount")
        PrintBasic.print_basic(self.high, format_data + "High")
        PrintBasic.print_basic(self.low, format_data + "Low")
        PrintBasic.print_basic(self.count, format_data + "Count")
        PrintBasic.print_basic(self.volume, format_data + "Volume")